[Libreoffice-commits] core.git: framework/source

Michael Stahl mstahl at redhat.com
Wed Jan 11 19:40:39 UTC 2017


 framework/source/services/desktop.cxx |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 7d0e3b32de2d1cad01ef973b03eaa27fff766f6e
Author: Michael Stahl <mstahl at redhat.com>
Date:   Wed Jan 11 20:35:15 2017 +0100

    framework: call disposing from disposing, not notifyTermination
    
    Don't rely on current implementation details of TerminateListener.
    
    Change-Id: I7977c73669f0ab5afac1c93be620e7aeebfe68a2

diff --git a/framework/source/services/desktop.cxx b/framework/source/services/desktop.cxx
index 22a8360..434435d 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -1121,11 +1121,11 @@ void SAL_CALL Desktop::disposing()
     m_xStarBasicQuitGuard.clear();
     m_xSWThreadManager.clear();
 
     // we need a copy because the notifyTermination might call the removeEventListener method
     std::vector< css::uno::Reference<css::frame::XTerminateListener> > xComponentDllListeners = m_xComponentDllListeners;
     for (auto& xListener: xComponentDllListeners)
     {
-        xListener->notifyTermination(aEvent);
+        xListener->disposing(aEvent);
     }
     xComponentDllListeners.clear();
     m_xComponentDllListeners.clear();
@@ -1121,11 +1121,11 @@ void SAL_CALL Desktop::disposing()
     m_xSWThreadManager.clear();
 
-    // we need a copy because the notifyTermination might call the removeEventListener method
+    // we need a copy because the disposing might call the removeEventListener method
     std::vector< css::uno::Reference<css::frame::XTerminateListener> > xComponentDllListeners = m_xComponentDllListeners;
     for (auto& xListener: xComponentDllListeners)


More information about the Libreoffice-commits mailing list